@@ -1,5 +1,5 @@
 import json
-from dsmigrator.logging import console
+from dsmigrator.logging import console, log
 import deepsecurity
 from deepsecurity.rest import ApiException
 import re
@@ -10,6 +10,7 @@ def to_snake(camel_case):
     pattern = re.compile(r"(?<!^)(?=[A-Z])")
     snake = pattern.sub("_", camel_case).lower()
     snake = snake.replace("application_type_i_d", "application_type_id")
+    snake = snake.replace("_i_d", "_id")
     return snake
 
 
@@ -234,27 +235,6 @@ class FirewallApiInstance(RestApiConfiguration):
         return object.name
 
 
-class ApplicationControlRulesetsApiInstance(RestApiConfiguration):
-    def __init__(self, NEW_API_KEY, overrides=False):
-        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
-        self.api_instance = deepsecurity.RulesetsApi(self.api_client)
-
-    def create(self, json, inventory_id):
-        ruleset = deepsecurity.Ruleset()
-        for key in json:
-            if not key == "ID":
-                setattr(ruleset, to_snake(key), json[key])
-        try:
-            self.api_instance.create_ruleset(ruleset, inventory_id, self.api_version)
-            return ruleset.name
-        except ApiException as e:
-            console.log(
-                "An exception occurred when calling RulesetsApi.create_ruleset: %s\n"
-                % e
-            )
-            pass
-
-
 class PolicyApiInstance(RestApiConfiguration):
     def __init__(self, NEW_API_KEY, overrides=False):
         RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
