@@ -1,16 +1,19 @@
-import sys
+import json
+import typing
 import os
+import sys
+from types import SimpleNamespace
+
 import deepsecurity
-from deepsecurity.rest import ApiException
 import requests
 import urllib3
-import urllib3
-import json
-from dsmigrator.logging import console, log
-from types import SimpleNamespace
-from dsmigrator.api_config import PolicyApiInstance
+from deepsecurity.rest import ApiException
 from rich.progress import Progress
 
+from dsmigrator.api_config import PolicyApiInstance
+from dsmigrator.migrator_utils import safe_request
+from dsmigrator.logging import console, log
+
 cert = False
 
 
@@ -44,18 +47,7 @@ def delete_cloud_one_policies(CLOUD_ONE_API_KEY: str):
 def ListAllPolicy(url_link_final, tenant1key):
     payload = {}
     url = url_link_final + "api/policies"
-    headers = {
-        "api-secret-key": tenant1key,
-        "api-version": "v1",
-        "Content-Type": "application/json",
-    }
-    response = requests.request(
-        "GET",
-        url,
-        headers=headers,
-        data=payload,
-        verify=cert,
-    )
+    response = safe_request(tenant1key, "GET", url, payload=payload, cert=cert)
     describe = str(response.text)
     oldpolicyname = []
     oldpolicyid = []
@@ -72,29 +64,16 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
     i = 0
     console.log("Getting Policy from Deep Security")
     for count, part in enumerate(policyIDs):
-
         payload = {}
         url = url_link_final + "api/policies/" + str(part)
-        headers = {
-            "api-secret-key": tenant1key,
-            "api-version": "v1",
-            "Content-Type": "application/json",
-        }
-        response = requests.request(
-            "GET",
-            url,
-            headers=headers,
-            data=payload,
-            verify=cert,
-        )
-
-        describe = str(response.text)
+        response = safe_request(tenant1key, "GET", url, payload=payload, cert=cert)
+        policy_string = str(response.text)
         i = i + 1
-        allofpolicy.append(describe)
+        allofpolicy.append(policy_string)
         console.log("#" + str(count) + " Policy ID: " + str(part))
-        rtscan = describe.find("realTimeScanConfigurationID")
+        rtscan = policy_string.find("realTimeScanConfigurationID")
         if rtscan != -1:
-            rtpart = describe[rtscan + 28 :]
+            rtpart = policy_string[rtscan + 28 :]
             startIndex = rtpart.find(":")
             if startIndex != -1:  # i.e. if the first quote was found
                 endIndex = rtpart.find(",", startIndex + 1)
@@ -102,9 +81,9 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
                     rtid = rtpart[startIndex + 1 : endIndex]
                     antimalwareconfig.append(str(rtid))
 
-        mscan = describe.find("manualScanConfigurationID")
+        mscan = policy_string.find("manualScanConfigurationID")
         if mscan != -1:
-            mpart = describe[mscan + 26 :]
+            mpart = policy_string[mscan + 26 :]
             startIndex = mpart.find(":")
             if startIndex != -1:  # i.e. if the first quote was found
                 endIndex = mpart.find(",", startIndex + 1)
@@ -112,9 +91,9 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
                     mid = mpart[startIndex + 1 : endIndex]
                     antimalwareconfig.append(str(mid))
 
-        sscan = describe.find("scheduledScanConfigurationID")
+        sscan = policy_string.find("scheduledScanConfigurationID")
         if sscan != -1:
-            spart = describe[sscan + 29 :]
+            spart = policy_string[sscan + 29 :]
             startIndex = spart.find(":")
             if startIndex != -1:  # i.e. if the first quote was found
                 endIndex = spart.find("}", startIndex + 1)
@@ -125,7 +104,24 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
     return antimalwareconfig, allofpolicy
 
 
-def validate_create(all_old, api_instance, type):
+def policy_validate_create(
+    all_old: typing.List[str], api_instance: PolicyApiInstance, type: str
+) -> typing.Dict[int, int]:
+    """
+    Takes in a list of json strings that represent policies, sets some key
+    settings, assigns the proper parent ID to each, creates each policy,
+    renames if necessary, and outputs a dictionary of form
+    {oldid: newid, ...} for future use.
+
+    Args:
+        all_old (typing.List[str]): A list containing strings of json data
+                                    representing policies
+        api_instance (PolicyApiInstance): From api_config, a wrapper SDK class
+        type (str): The type of output for printing purposes
+
+    Returns:
+        typing.Dict[int, int]: dict of form {oldid:newid, ...}
+    """
     all_new = []
     id_dict = {}
     for count, dirlist in enumerate(all_old):
@@ -135,13 +131,21 @@ def validate_create(all_old, api_instance, type):
         oldname = oldjson["name"]
         oldid = oldjson["ID"]
         # cleanup input
-        # policysettings = oldjson.get("policySettings")
         if "policySettings" in oldjson.keys():
             oldjson["policySettings"]["platformSettingAgentCommunicationsDirection"] = {
                 "value": "Agent/Appliance Initiated"
             }
-        if "parentID" in oldjson.keys():
-            oldjson["parentID"] = id_dict[oldjson["parentID"]]
+        # Modify parent ID. If errors, to prevent wasted time, create policy at base level.
+        try:
+            if "parentID" in oldjson.keys():
+                oldjson["parentID"] = id_dict[oldjson["parentID"]]
+        except Exception as e:
+            log.exception(e)
+            log.error(
+                "ParentID error. Creating policy at base level, please set inheritance manually."
+            )
+            del oldjson["parentID"]
+            pass
         while namecheck != -1:
             try:
                 newname = api_instance.create(oldjson)
@@ -169,7 +173,7 @@ def validate_create(all_old, api_instance, type):
                     rename = rename + 1
                 else:
                     log.exception(e)
-                    log.critical(
+                    log.error(
                         f"{oldname} could not be transferred. Please transfer manually."
                     )
                     namecheck = -1
@@ -180,7 +184,9 @@ def validate_create(all_old, api_instance, type):
 cert = False
 
 
-def AddPolicy(allofpolicy, NEW_API_KEY):
+def AddPolicy(allofpolicy: typing.List[str], NEW_API_KEY: str) -> typing.Dict[int, int]:
     console.log("Creating Policy to Tenant 2 with new ID")
     if allofpolicy:
-        return validate_create(allofpolicy, PolicyApiInstance(NEW_API_KEY), "policy")
+        return policy_validate_create(
+            allofpolicy, PolicyApiInstance(NEW_API_KEY), "policy"
+        )
